@@ -5,6 +5,7 @@ import sys
 import signal
 import ConfigParser
 import redis
+from rediscluster import RedisCluster as StrictRedisCluster
 from sharq.utils import (is_valid_identifier, is_valid_interval,
                          is_valid_requeue_limit, generate_epoch,
                          serialize_payload, deserialize_payload)
@@ -52,12 +53,20 @@ class SharQ(object):
                 unix_socket_path=self._config.get('redis', 'unix_socket_path')
             )
         elif redis_connection_type == 'tcp_sock':
-            self._r = redis.StrictRedis(
-                db=db,
-                host=self._config.get('redis', 'host'),
-                port=self._config.get('redis', 'port')
-            )
-
+            isclustered = False    
+            if self._config.has_option('redis', 'clustered'):
+                isclustered = self._config.getboolean('redis', 'clustered')
+                
+            if isclustered:
+                startup_nodes = [{"host":self._config.get('redis', 'host'), "port":self._config.get('redis', 'port')}]
+                self._r = StrictRedisCluster(startup_nodes=startup_nodes, decode_responses=False,
+                                             skip_full_coverage_check=True, socket_timeout=5)
+            else:
+                self._r = redis.StrictRedis(
+                    db=db,
+                    host=self._config.get('redis', 'host'),
+                    port=self._config.get('redis', 'port')
+                )
         self._load_lua_scripts()
 
     def _load_config(self):
@@ -438,3 +447,60 @@ class SharQ(object):
                 '`queue_id` should be accompanied by `queue_type`.')
 
         return response
+
+    def deep_status(self):
+        """
+        To check the availability of redis. If redis is down get will throw exception
+        :return: value or None
+        """
+        return self._r.get('sharq:deep_status:{}'.format(self._key_prefix))
+    
+    def clear_queue(self, queue_type=None, queue_id=None, purge_all=False):
+        """clear the all entries in queue with particular queue_id
+        and queue_type. It takes an optional argument, 
+        purge_all : if True, then it will remove the related resources
+        from the redis.
+        """
+        if queue_id is None or not is_valid_identifier(queue_id):
+            raise BadArgumentException('`queue_id` has an invalid value.')
+
+        if queue_type is None or not is_valid_identifier(queue_type):
+            raise BadArgumentException('`queue_type` has an invalid value.')
+
+        response = {
+            'status': 'Failure',
+            'message': 'No queued calls found'
+            }
+        # remove from the primary sorted set
+        primary_set = '{}:{}'.format(self._key_prefix, queue_type)
+        queued_status = self._r.zrem(primary_set, queue_id)
+        if queued_status:
+            response.update({'status': 'Success', 
+                    'message': 'Successfully removed all queued calls'})
+        # do a full cleanup of reources
+        # although this is not necessary as we don't remove resources 
+        # while dequeue operation
+        job_queue_list = '{}:{}:{}'.format(self._key_prefix, queue_type, queue_id)
+        if queued_status and purge_all:
+            job_list = self._r.lrange(job_queue_list, 0, -1)
+            pipe = self._r.pipeline()
+            # clear the payload data for job_uuid
+            for job_uuid in job_list:
+                if job_uuid is None:
+                    continue
+                payload_set = '{}:payload'.format(self._key_prefix)
+                job_payload_key = '{}:{}:{}'.format(queue_type, queue_id, job_uuid)
+                pipe.hdel(payload_set, job_payload_key)
+            # clear jobrequest interval
+            interval_set = '{}:interval'.format(self._key_prefix)
+            job_interval_key = '{}:{}'.format(queue_type, queue_id)
+            pipe.hdel(interval_set, job_interval_key)
+            # clear job_queue_list
+            pipe.delete(job_queue_list)
+            pipe.execute()
+            response.update({'status': 'Success', 
+                    'message': 'Successfully removed all queued calls and purged related resources'})
+        else:
+            # always delete the job queue list
+            self._r.delete(job_queue_list)
+        return response
